@@ -2,7 +2,7 @@ package WebService::ILS;
 
 use Modern::Perl;
 
-our $VERSION = "0.10";
+our $VERSION = "0.11";
 
 =encoding utf-8
 
@@ -279,6 +279,10 @@ Sort order can be added after option with ":", eg
 
 =back
 
+=head2 item_metadata ($item_id)
+
+=head3 Returns item record
+
 =head2 item_availability ($item_id)
 
 =head3 Returns item availability record:
@@ -339,6 +343,10 @@ sub _parse_sort_string {
     return $sort;
 }
 
+sub item_metadata {
+    die "item_metadata() not implemented";
+}
+
 sub item_availability {
     die "item_availability() not implemented";
 }
@@ -708,7 +716,7 @@ sub process_json_response {
 
     local $@;
 
-    my $data = eval { from_json( $content ) };
+    my $data = $content ? eval { from_json( $content ) } : {};
     die "$@\nResponse:\n".$response->as_string if $@;
 
     return $data unless $success_callback;
