@@ -37,7 +37,7 @@ See L<WebService::ILS>
 use Carp;
 use HTTP::Request::Common;
 use URI::Escape;
-use Data::Dumper;
+use JSON qw(to_json);
 
 use parent qw(WebService::ILS::JSON);
 
@@ -367,6 +367,11 @@ sub facet_search {
     return $self->_search_result_xlate( $self->native_facet_search(@_) );
 }
 
+sub item_metadata {
+    my $self = shift;
+    return $self->_item_xlate( $self->native_item(@_) );
+}
+
 =head1 CIRCULATION METHOD SPECIFICS
 
 Differences to general L<WebService::ILS> interface
@@ -402,22 +407,36 @@ sub place_hold {
     my $url = $self->circulation_action_url("/holds/$isbn", @_);
     my $request = HTTP::Request::Common::POST( $url );
     my $response = $self->_request_with_auth($request);
-    my $content = $response->decoded_content;
-    my $content_type = $response->header('Content-Type');
-    local $@;
-    my $res = $content_type && $content_type =~ m!application/json!
-       ? eval { from_json( $content ) }
-       : undef;
-    $res ||= {message => "Error response: $content"}; # response is rather useless
+    unless ($response->is_success) {
+        $self->process_json_error_response($response, sub {
+            my ($data) = @_;
+            if (my $message = $data->{message}) {
+                return 1 if $message =~ m/already exists/i;
+                die $message;
+            }
+            die $self->_error_from_json($data) || "Cannot place hold: ".to_json($data);
+        });
+    }
 
-    my $holds = $self->holds(@_) or die "Cannot place hold, unkmown error";
-    foreach my $i (@{ $holds->{items} }) {
-        if ($i->{isbn} eq $isbn) {
-            $i->{total} = scalar @{ $holds->{items} };
-            return $i;
+    if (my $holds = $self->holds(@_)) {
+        foreach my $i (@{ $holds->{items} }) {
+            if ($i->{isbn} eq $isbn) {
+                $i->{total} = $holds->{total};
+                return $i;
+            }
         }
     }
-    die $res->{message} || "Cannot place hold, unknown error";
+
+    my $content = $response->decoded_content;
+    my $content_type = $response->header('Content-Type');
+    my $error;
+    if ($content_type && $content_type =~ m!application/json!) {
+        if (my $data = eval { from_json( $content ) }) {
+            $error = $self->_error_from_json($data);
+        }
+    }
+
+    die $error || "Cannot place hold:\n$content";
 }
 
 sub remove_hold {
@@ -425,18 +444,19 @@ sub remove_hold {
     my $isbn = shift or croak "No isbn";
 
     my $url = $self->circulation_action_url("/holds/$isbn", @_);
-    return $self->with_delete_request(
-        \&_basic_callback,
-        sub {
+    my $request = HTTP::Request::Common::DELETE( $url );
+    my $response = $self->_request_with_auth($request);
+    unless ($response->is_success) {
+        return $self->process_json_error_response($response, sub {
             my ($data) = @_;
             if (my $message = $data->{message}) {
                 return 1 if $message =~ m/not exists|expired/i;
                 die $message;
             }
-            die Dumper($data);
-        },
-        $url
-    );
+            die $self->_error_from_json($data) || "Cannot remove hold: ".to_json($data);
+        });
+    }
+    return 1;
 }
 
 =head2 checkouts ()
@@ -511,35 +531,27 @@ sub renew {
             return $i;
         }
     }
-    die $res->{output} || "Cannot renew, unkmown error";
+    die $res->{output} || "Cannot renew, unknown error";
 }
 
 sub return {
     my $self = shift;
     my $isbn = shift or croak "No isbn";
 
-    my $return_checkout;
-    my $checkouts = $self->checkouts(@_) or die "Cannot return, unknown error";
-    foreach my $i (@{ $checkouts->{items} }) {
-        if ($i->{isbn} eq $isbn) {
-            $return_checkout = 1;
-            last;
-        }
-    }
-
-    my $url = $self->circulation_action_url("/".($return_checkout ? "checkouts" : "holds")."/$isbn", @_);
-    return $self->with_delete_request(
-        \&_basic_callback,
-        sub {
+    my $url = $self->circulation_action_url("/checkouts/$isbn", @_);
+    my $request = HTTP::Request::Common::DELETE( $url );
+    my $response = $self->_request_with_auth($request);
+    unless ($response->is_success) {
+        return $self->process_json_error_response($response, sub {
             my ($data) = @_;
             if (my $message = $data->{message}) {
                 return 1 if $message =~ m/not exists|expired/i;
                 die $message;
             }
-            die Dumper($data);
-        },
-        $url
-    );
+            die "Cannot return: ".to_json($data);
+        });
+    }
+    return 1;
 }
 
 =head1 NATIVE METHODS
@@ -616,7 +628,7 @@ sub native_item {
     my $self = shift;
     my $isbn = shift or croak "No isbn";
 
-    my $url = $self->api_url("/title/$isbn");
+    my $url = $self->title_url($isbn);
     return $self->get_response($url);
 }
 
@@ -624,7 +636,7 @@ sub native_item_summary {
     my $self = shift;
     my $isbn = shift or croak "No isbn";
 
-    my $url = $self->api_url("/title/$isbn/summary");
+    my $url = $self->title_url("$isbn/summary");
     return $self->get_response($url);
 }
 
