@@ -31,6 +31,12 @@ sub products_url {
     return $self->library_action_base_url."/search";
 }
 
+sub title_url {
+    my $self = shift;
+    my $isbn = shift or croak "No isbn";
+    return $self->library_action_base_url."/titles/$isbn";
+}
+
 sub _request_with_token {
     my $self = shift;
     my $request = shift or croak "No request";
