@@ -301,8 +301,6 @@ sub patron {
     return $self->_result_xlate($self->native_patron, \%PATRON_XLATE);
 }
 
-# Holds (reserves)
-
 my %HOLDS_XLATE = (
     totalItems => 'total',
 );
@@ -318,7 +316,13 @@ sub holds {
     my $items = delete ($holds->{holds}) || [];
 
     my $res = $self->_result_xlate($holds, \%HOLDS_XLATE);
-    $res->{items} = [map $self->_result_xlate($_, \%HOLDS_ITEM_XLATE), @$items];
+    $res->{items} = [
+        map {
+            my $item = $self->_result_xlate($_, \%HOLDS_ITEM_XLATE);
+            my $metadata = $self->_item_metadata($_);
+            my $i = {%$item, %$metadata}; # we need my $i, don't ask me why...
+        } @$items
+    ];
     return $res;
 }
 
